from flask import Flask, request, jsonify
import matplotlib.pyplot as plt
import seaborn as sns
import tensorflow as tf
import cv2
import os
import random
import numpy as np # linear algebra
import pandas as pd # data processing, CSV file I/O (e.g. pd.read_csv)
from flask_cors import CORS


app = Flask(__name__)
CORS(app)

model = tf.keras.models.load_model('model/shakya.h5')
app.config['UPLOAD'] = './upload'
labels = ['thekka', 'mahogani','jack','Other']
img_size = 224

@app.route('/')
def hello_world():  # put application's code here
    return 'Hello World!'

@app.route('/predict', methods=['POST'])
def predict_t():
    if 'file' not in request.files:
        return jsonify({'error': "file not found"})
    file = request.files['file']
    if file.filename == '':
        return jsonify({'error': "file not found"})
    path = os.path.join(app.config['UPLOAD'], file.filename)
    file.save(path)
    x = []
    img_arr = cv2.imread(path, cv2.IMREAD_COLOR)
    resized_arr = cv2.resize(img_arr, (img_size, img_size))
    # Normalize the data
    x = np.array(resized_arr) / 255
    x = x.reshape(-1, img_size, img_size, 3)
    predictions = model.predict(x)
    predicted_classes = predictions.argmax(axis=-1)
    predicted_classes[:1]


    res = {
        "result": labels[predicted_classes[0]]
    }

    return jsonify(res)


if __name__ == '__main__':
    app.run()
