import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import '../screens/wood_type.dart';
import '../screens/home.dart';
import '../helper/enums.dart';



class CustomBottomNavBar extends StatefulWidget {
  final MenuState? selectedMenu;

  const CustomBottomNavBar({super.key, required this.selectedMenu});
  @override
  State<CustomBottomNavBar> createState() => _CustomBottomNavBarState();
}

class _CustomBottomNavBarState extends State<CustomBottomNavBar> {
  late MenuState _selectedMenuState;

  @override
  void initState() {
    _selectedMenuState = widget.selectedMenu!;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    const Color inActiveIconColor = Color.fromARGB(255, 0, 0, 0);
    // ignore: constant_identifier_names
    const Color ActiveIconColor =  Color.fromARGB(255, 182, 124, 47);
    return Container(
      padding: const EdgeInsets.symmetric(vertical: 14),
      decoration: BoxDecoration(
        color:const Color.fromARGB(232, 245, 235, 215),
        boxShadow: [
          BoxShadow(
            offset: const Offset(0, -15),
            blurRadius: 20,
            color:const Color.fromARGB(90, 103, 218, 9).withOpacity(0.08),
          ),
        ],
        borderRadius: const BorderRadius.only(
          topLeft: Radius.circular(20),
          topRight: Radius.circular(20),
        ),
      ),
      child: SafeArea(
          top: false,
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: [
              Transform.scale(
                  scale: MenuState.home == _selectedMenuState ? 2 : 1.5,
                  child: IconButton(
                    icon: SvgPicture.asset(
                      "assets/icons/Star Icon.svg",
                      // ignore: deprecated_member_use
                      color: MenuState.home == _selectedMenuState
                          ? ActiveIconColor
                          : inActiveIconColor,
                    ),
                    onPressed: () => {
                      Navigator.of(context).pushReplacement(
                          MaterialPageRoute(builder: (context) => const HomePage()))
                    },
                  )),

              Transform.scale(
                  scale: MenuState.type == _selectedMenuState ? 1.5 : 1.2,
                  child: IconButton(
                    icon: SvgPicture.asset(
                      "assets/icons/Gift Icon.svg",
                      // ignore: deprecated_member_use
                      color: MenuState.type == _selectedMenuState
                          ? ActiveIconColor
                          : inActiveIconColor,
                    ),
                    onPressed: () => {
                      Navigator.of(context).pushReplacement(
                          MaterialPageRoute(builder: (context) =>  const WoodType()))
                    },
                  ))
            ],
          )),
    );
  }
}
