import 'package:flutter/material.dart';
import 'package:timber_tech/components/custom_surfix_icon.dart';
import 'package:timber_tech/components/form_error.dart';
import 'package:timber_tech/components/snackbar.dart';
import 'package:timber_tech/screens/home.dart';

import '../../../components/default_button.dart';
import '../../helper/size_config.dart';

class KeyboardUtil {
  static void hideKeyboard(BuildContext context) {
    FocusScopeNode currentFocus = FocusScope.of(context);
    if (!currentFocus.hasPrimaryFocus) {
      currentFocus.unfocus();
    }
  }
}

class SignInScreen extends StatefulWidget {
  const SignInScreen({super.key});

  @override
  // ignore: library_private_types_in_public_api
  _SignInScreenState createState() => _SignInScreenState();
}

class _SignInScreenState extends State<SignInScreen> {
  final _formKey = GlobalKey<FormState>();
  final emailController = TextEditingController();
  final passwordController = TextEditingController();
  List<String?> errors = [];
  bool circular = false;

  void addError({String? error}) {
    if (!errors.contains(error)) {
      setState(() {
        errors.add(error);
      });
    }
  }

  void removeError({String? error}) {
    if (errors.contains(error)) {
      setState(() {
        errors.remove(error);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    SizeConfig().init(context);

    return Scaffold(
        extendBodyBehindAppBar: true,
        backgroundColor: const Color.fromARGB(255, 255, 255, 255),
        body: SingleChildScrollView(
            child: Column(children: [
          Container(
            height: 240,
            decoration: const BoxDecoration(
                image: DecorationImage(
                    image: AssetImage('assets/images/lg.jpeg'),
                    fit: BoxFit.fill)),
          ),
          Column(children: [
            Text(
              "TimberTech",
              style: TextStyle(
                color: const Color.fromARGB(255, 0, 0, 0),
                fontSize: getRelativeScreenWidth(40),
                fontWeight: FontWeight.bold,
              ),
            ),
            Form(
              key: _formKey,
              child: Column(
                children: [
                  Container(
                    padding: const EdgeInsets.all(8.0),
                    child: emailFormField(),
                  ),
                  Container(
                    padding: const EdgeInsets.all(8.0),
                    child: passwordFormField(),
                  ),
                  FormError(errors: errors),
                  SizedBox(height: getRelativeScreenHeight(10)),
                  DefaultButton(
                    text: "Login",
                    press: () async {
                      if (_formKey.currentState!.validate()) {
                        _formKey.currentState!.save();
                        KeyboardUtil.hideKeyboard(context);
                        errors = [];
                        setState(() {
                          circular = true;
                        });

                        if (passwordController.text == '1234' &&
                            emailController.text == 'admin@gmail.com') {
                          Navigator.of(context).pushReplacement(
                              MaterialPageRoute(
                                  builder: (context) => const HomePage()));
                        } else {
                          snackBar(context, 'check email or password');
                        }
                      }
                    },
                  ),
                  const SizedBox(height: 20),
                  circular ? const CircularProgressIndicator() : const Text(''),
                ],
              ),
            ),
          ]),
        ])));
  }

  TextFormField passwordFormField() {
    return TextFormField(
      obscureText: true,
      style: const TextStyle(color: Color.fromARGB(255, 8, 8, 8)),
      controller: passwordController,
      validator: (value) {
        if (value!.isEmpty) {
          addError(error: 'Please Enter your password');
          return "";
        }
        return null;
      },
      decoration: InputDecoration(
        border: OutlineInputBorder(
          borderRadius: BorderRadius.circular(40.0),
        ),
        labelText: "Password",
        hintText: "Enter your password",
        labelStyle: const TextStyle(color: Color.fromARGB(255, 17, 17, 17)),
        hintStyle: const TextStyle(color: Color.fromARGB(88, 94, 90, 90)),
        floatingLabelBehavior: FloatingLabelBehavior.always,
        suffixIcon: const CustomSurffixIcon(svgIcon: "assets/icons/Lock.svg"),
      ),
    );
  }

  TextFormField emailFormField() {
    final RegExp emailValidatorRegExp =
        RegExp(r"^[a-zA-Z0-9.]+@[a-zA-Z0-9]+\.[a-zA-Z]+");

    return TextFormField(
      style: const TextStyle(color: Color.fromARGB(255, 0, 0, 0)),
      keyboardType: TextInputType.emailAddress,
      controller: emailController,
      validator: (value) {
        if (value!.isEmpty) {
          addError(error: 'Please Enter your email');
          return "";
        } else if (!emailValidatorRegExp.hasMatch(value)) {
          addError(error: 'Please Enter Valid Email');
          return "";
        }
        return null;
      },
      decoration: InputDecoration(
        border: OutlineInputBorder(
          borderRadius: BorderRadius.circular(40.0),
        ),
        labelText: "Email",
        labelStyle: const TextStyle(color: Color.fromARGB(255, 0, 0, 0)),
        hintStyle: const TextStyle(color: Color.fromARGB(88, 94, 90, 90)),
        hintText: "Enter your email",
        floatingLabelBehavior: FloatingLabelBehavior.always,
        suffixIcon: const CustomSurffixIcon(svgIcon: "assets/icons/Mail.svg"),
      ),
    );
  }
}
