import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:http/http.dart' as http;
import '../components/coustom_bottom_nav_bar.dart';
import '../components/curve_btn.dart';
import '../components/snackbar.dart';
import '../helper/enums.dart';

class WoodType extends StatefulWidget {
  const WoodType({super.key});

  @override
  State<WoodType> createState() => _WoodTypeState();
}

class _WoodTypeState extends State<WoodType> {
  bool isImageSelected = false;
  bool istype = true;
  String type = "";
  File? imageFile;

  Future<void> uploadImage(File imageFile) async {
    String url = 'http://10.0.2.2:5000/predict';
    var request = http.MultipartRequest('POST', Uri.parse(url));
    request.files
        .add(await http.MultipartFile.fromPath('file', imageFile.path));

    var response = await request.send();
    if (response.statusCode == 200) {
      List<String> parts;
      response.stream.transform(utf8.decoder).join().then((value) => {
            parts = value.split(':'),
            setState(() {
              type = parts[1];
              parts = type.split("}");
              type = parts[0];
              type = type.replaceAll('"', '');
              istype = false;
            })
          });
    } else {
      // ignore: use_build_context_synchronously
      snackBar(context, "Error");
    }
  }

  _selected() {
    if (!istype) {
      return 250.0;
    }
    return isImageSelected ? 450.0 : 300.0;
  }

  _pickImagefromGallery() async {
    try {
      final pickedImage =
          await ImagePicker().pickImage(source: ImageSource.gallery);
      if (pickedImage != null) {
        setState(() {
          imageFile = File(pickedImage.path);
          isImageSelected = true;
        });
      } else {
        // ignore: use_build_context_synchronously
        snackBar(context, "Error");
      }
    } catch (e) {
      // ignore: use_build_context_synchronously
      snackBar(context, "Error");
    }
  }

  _pickImagefromCamera() async {
    try {
      final pickedImage =
          await ImagePicker().pickImage(source: ImageSource.camera);
      if (pickedImage != null) {
        setState(() {
          imageFile = File(pickedImage.path);
          isImageSelected = true;
        });
      } else {
        // ignore: use_build_context_synchronously
        snackBar(context, "Error");
      }
    } catch (e) {
      // ignore: use_build_context_synchronously
      snackBar(context, "Error");
    }
  }

  void _removeImage() {
    setState(() {
      imageFile = null;
      isImageSelected = false;
    });
  }

  void _remove() {
    setState(() {
      istype = true;
    });
  }

  @override
  Widget build(BuildContext context) {
    {
      return Scaffold(
          backgroundColor: const Color.fromARGB(255, 248, 241, 227),
          appBar: PreferredSize(
            preferredSize: const Size.fromHeight(70),
            child: AppBar(
                centerTitle: true,
                 backgroundColor:const Color.fromARGB(255, 182, 124, 47),
                flexibleSpace: const ClipRRect(
                  borderRadius: BorderRadius.only(
                      bottomRight: Radius.circular(50),
                      bottomLeft: Radius.circular(50)),
                 
                ),
                title: const Text('Wood Type Prediction',
                    style:
                        TextStyle(fontWeight: FontWeight.bold, fontSize: 24)),
                shape: const RoundedRectangleBorder(
                    borderRadius: BorderRadius.only(
                        bottomRight: Radius.circular(50),
                        bottomLeft: Radius.circular(50)))),
          ),
          extendBodyBehindAppBar: true,
          body:Container(
          decoration: const BoxDecoration(
            image: DecorationImage(
              image: AssetImage('assets/images/bg3.jpg'),
              fit: BoxFit.cover,
            ),
          ),child: Center(
            child: Card(
              elevation: 50,
              shadowColor: Colors.black,
              color: const Color.fromARGB(255, 247, 220, 184),
              child: SizedBox(
                width: 300,
                height: _selected(),
                child: Padding(
                  padding: const EdgeInsets.all(20.0),
                  child: istype
                      ? Column(
                          children: [
                            isImageSelected
                                ? Expanded(
                                    child: ClipRRect(
                                      borderRadius: const BorderRadius.vertical(
                                          top: Radius.circular(8.0)),
                                      child: Image.file(imageFile!,
                                          fit: BoxFit.cover,
                                          width: 300,
                                          height: 100),
                                    ),
                                  )
                                : const SizedBox(
                                    height: 40,
                                  ),
                            const SizedBox(
                              height: 30,
                            ),
                            isImageSelected
                                ? CurvedGradientButton(
                                    gradientColors: const [
                                Color.fromARGB(255, 167, 91, 29),
                                Color.fromARGB(255, 155, 102, 3)
                                    ],
                                    text: "Predict",
                                    onPressed: () async {
                                      await uploadImage(imageFile!);
                                    },
                                    width: 100,
                                  )
                                : CurvedGradientButton(
                                    gradientColors: const [
                                     Color.fromARGB(255, 167, 91, 29),
                                Color.fromARGB(255, 155, 102, 3)
                                    ],
                                    text: "Camera",
                                    onPressed: () async {
                                      await _pickImagefromCamera();
                                    },
                                    width: 100,
                                  ),
                            const SizedBox(
                              height: 30,
                            ),
                            isImageSelected
                                ? CurvedGradientButton(
                                    gradientColors: const [
                                 Color.fromARGB(255, 167, 91, 29),
                                Color.fromARGB(255, 155, 102, 3)
                                    ],
                                    text: "Remove",
                                    onPressed: () {
                                      _removeImage();
                                    },
                                    width: 100,
                                  )
                                : CurvedGradientButton(
                                    gradientColors: const [
                                Color.fromARGB(255, 167, 91, 29),
                                Color.fromARGB(255, 155, 102, 3)
                                    ],
                                    text: "Gallery",
                                    onPressed: () async {
                                      await _pickImagefromGallery();
                                    },
                                    width: 100,
                                  )
                          ],
                        )
                      : Column(
                          children: [
                            const SizedBox(
                              height: 30,
                            ),
                            const Text("Prediction",
                                style: TextStyle(
                                    fontWeight: FontWeight.bold, fontSize: 22)),
                            const SizedBox(
                              height: 30,
                            ),
                            Text(type,
                                style: const TextStyle(
                                    fontWeight: FontWeight.bold, fontSize: 20)),
                            const SizedBox(
                              height: 30,
                            ),
                            CurvedGradientButton(
                              gradientColors: const [
                                Color.fromARGB(255, 167, 91, 29),
                                Color.fromARGB(255, 155, 102, 3)
                              ],
                              text: "OK",
                              onPressed: () async {
                                _remove();
                              },
                              width: 100,
                            )
                          ],
                        ),
                ),
              ),
            ),
          )),
          bottomNavigationBar:
              const CustomBottomNavBar(selectedMenu: MenuState.type));
    }
  }
}
